# -*- coding: iso-8859-1 -*-
# this file is automatically created by setup.py
install_purelib = '\\'
install_platlib = '\\patool-1.12.data\\platlib'
install_lib = '\\'
install_headers = '\\patool-1.12.data\\headers'
install_scripts = '\\patool-1.12.data\\scripts'
config_dir = '\\patool-1.12.data\\data\\share\\patool'
install_data = '\\patool-1.12.data\\data'
name = 'patool'
version = '1.12'
author = 'Bastian Kleineidam'
author_email = 'bastian.kleineidam@web.de'
maintainer = 'Bastian Kleineidam'
maintainer_email = 'bastian.kleineidam@web.de'
url = 'http://wummel.github.io/patool/'
license = 'GPL'
description = 'portable archive file manager'
long_description = 'Various archive formats can be created, extracted, tested, listed,\nsearched, compared and repacked by patool. The advantage of patool\nis its simplicity in handling archive files without having to remember\na myriad of programs and options.\n\nThe archive format is determined by the file(1) program and as a\nfallback by the archive file extension.\n\npatool supports 7z (.7z), ACE (.ace), ADF (.adf), ALZIP (.alz), APE (.ape),\nAR (.a), ARC (.arc), ARJ (.arj), BZIP2 (.bz2),\nCAB (.cab), COMPRESS (.Z), CPIO (.cpio),\nDEB (.deb), DMS (.dms), FLAC (.flac), GZIP (.gz), ISO (.iso), LRZIP (.lrz),\nLZH (.lha, .lzh), LZIP (.lz), LZMA (.lzma), LZOP (.lzo), RPM (.rpm),\nRAR (.rar), RZIP (.rz), SHN (.shn), TAR (.tar), XZ (.xz), ZIP (.zip, .jar),\nZOO (.zoo) and ZPAQ (.zpaq) formats.\nIt relies on helper applications to handle those archive formats\n(for example bzip2 for BZIP2 archives).\n\nThe archive formats TAR, ZIP, BZIP2 and GZIP\nare supported natively and do not require helper applications to be\ninstalled.\n'
keywords = ['archiver', 'archive', 'compression', 'commandline', 'manager']
platforms = ['UNKNOWN']
fullname = 'patool-1.12'
contact = 'Bastian Kleineidam'
contact_email = 'bastian.kleineidam@web.de'
release_date = "17.1.2016"
